summaryrefslogtreecommitdiff
path: root/silx/gui/plot/items/complex.py
diff options
context:
space:
mode:
Diffstat (limited to 'silx/gui/plot/items/complex.py')
-rw-r--r--silx/gui/plot/items/complex.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/silx/gui/plot/items/complex.py b/silx/gui/plot/items/complex.py
index ba57e85..535b0a9 100644
--- a/silx/gui/plot/items/complex.py
+++ b/silx/gui/plot/items/complex.py
@@ -29,7 +29,7 @@ from __future__ import absolute_import
__authors__ = ["Vincent Favre-Nicolin", "T. Vincent"]
__license__ = "MIT"
-__date__ = "19/01/2018"
+__date__ = "14/06/2018"
import logging
@@ -37,7 +37,7 @@ import numpy
from silx.third_party import enum
-from ..Colormap import Colormap
+from ...colors import Colormap
from .core import ColormapMixIn, ItemChangedType
from .image import ImageBase
@@ -229,7 +229,7 @@ class ImageComplexData(ImageBase, ColormapMixIn):
def setColormap(self, colormap, mode=None):
"""Set the colormap for this specific mode.
:param ~silx.gui.plot.Colormap.Colormap colormap: The colormap
:param Mode mode:
If specified, set the colormap of this specific mode.
Default: current mode.
@@ -249,7 +249,7 @@ class ImageComplexData(ImageBase, ColormapMixIn):
:param Mode mode:
If specified, get the colormap of this specific mode.
Default: current mode.
- :rtype: ~silx.gui.plot.Colormap.Colormap
+ :rtype: ~silx.gui.colors.Colormap
"""
if mode is None:
mode = self.getVisualizationMode()
@@ -229,7 +229,7 @@ class ImageComplexData(ImageBase, ColormapMixIn):
def setColormap(self, colormap, mode=None):
"""Set the colormap for this specific mode.
- :param ~silx.gui.plot.Colormap.Colormap colormap: The colormap
+ :param ~silx.gui.colors.Colormap colormap: The colormap
:param Mode mode:
If specified, set the colormap of this specific mode.